precision mediump float;

uniform sampler2D texture;
#define debug 1

#if debug
uniform int Orientation;
uniform int BlurAmount;
uniform float BlurScale;
uniform float BlurStrength;
uniform vec2 TexelSize;
#endif
varying mediump vec2 vTexCoord;

float Gaussian (float x, float deviation)
{
    return (1.0 / sqrt(2.0 * 3.141592 * deviation)) * exp(-((x * x) / (2.0 * deviation)));  
}

void main()
{
    
#if debug
    // Locals
    float halfBlur = float(BlurAmount) * 0.5;
    vec4 colour = vec4(0.0);
    vec4 texColour = vec4(0.0);
    
    // Gaussian deviation
    float deviation = halfBlur * 0.35;
    deviation *= deviation;
    float strength = 1.0 - BlurStrength;

    vec2 uv = vec2(vTexCoord.x, 1.0 - vTexCoord.y);

    if ( Orientation == 0 )
    {
        // Horizontal blur
        for (int i = 0; i < 50; ++i)
        {
            if ( i >= BlurAmount )
                break;
            
            float offset = float(i) - halfBlur;
            texColour = texture2D(texture, uv + vec2(offset * TexelSize.x * BlurScale, 0.0)) * Gaussian(offset * strength, deviation);
            colour += texColour;
        }
    }
    else
    {
        // Vertical blur
        for (int i = 0; i < 50; ++i)
        {
            if ( i >= BlurAmount )
                break;
            
            float offset = float(i) - halfBlur;
            texColour = texture2D(texture, uv + vec2(0.0, offset * TexelSize.y * BlurScale)) * Gaussian(offset * strength, deviation);
            colour += texColour;
        }
    }

    gl_FragColor = colour;//clamp(colour, 0.0, 1.0);
    gl_FragColor.a = 0.8;
#else
    gl_FragColor = texture2D(texture, vec2(vTexCoord.x, 1.0 - vTexCoord.y));
#endif
}
